"""
cursor
===============================================================================
"""

import wx
from wx.lib.embeddedimage import PyEmbeddedImage

cursors = {}

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgBAMAAACBVGfHAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JgAAgIQAAPoAAACA6AAAdTAAAOpgAAA6mAAAF3CculE8AAAAD1BMVEUBAgPAwMAA"
    "AACAgID///9hUlqkAAAAAXRSTlMAQObYZgAAAAFiS0dEBI9o2VEAAAAHdElNRQfhCBIOEg85"
    "efYaAAAAQUlEQVQoz2NgoAoQRBcQMkQTYFZCE2FUQhcxQhcRUlJCN0QB3RAmNHsMGNCUCDCg"
    "KwE61wBNQBhNE4ORAsMoAAIAYm8DsPm51CwAAAAldEVYdGRhdGU6Y3JlYXRlADIwMTctMDgt"
    "MThUMTQ6MTc6MzYrMDI6MDDbBp0NAAAAJXRFWHRkYXRlOm1vZGlmeQAyMDE3LTA4LTE4VDE0"
    "OjE4OjE1KzAyOjAwKJ1j3AAAAABJRU5ErkJggg==").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['Default'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAACXBIWXMAAAsTAAALEwEAmpwY"
    "AAAArUlEQVRYhe2VQQ7DIAwE130ZX/PPlpdtDy1VCdBTsXPAEpckkmcnljFJyKxHavcDcFuA"
    "WmvYZE4BSEb1ByR1h6QAiKSu73acwQBJSLIwC7P07+UUYqEz0NKbmcIsrNJHWfgYaOkvcNst"
    "WLuMmvbhg8Xzf9V0D5hZ/CIiCXdvA2AA4O4K+wXAK/l3w1LKMBfbAH5pD5mBVZPdBu55HUdW"
    "N4QZlW7gAByAA3AA0gGeYlZtKH9TdOAAAAAASUVORK5CYII=").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['Draw'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgAgMAAAAOFJJnAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JgAAgIQAAPoAAACA6AAAdTAAAOpgAAA6mAAAF3CculE8AAAADFBMVEUBAgMAAACA"
    "gID///9fpk1YAAAAAXRSTlMAQObYZgAAAAFiS0dEAxEMTPIAAAAHdElNRQfhCBIOEg85efYa"
    "AAAARElEQVQY02NggAMHDEYDlBZLRRdhcIMxPBOgDMYwKIMpFCYUCjNpKky1CExEQQAmxAJ3"
    "gCjcAVBVjAwCaAy4FEIxbQEAg2EG96jiK74AAAAldEVYdGRhdGU6Y3JlYXRlADIwMTctMDgt"
    "MThUMTQ6MTc6MzYrMDI6MDDbBp0NAAAAJXRFWHRkYXRlOm1vZGlmeQAyMDE3LTA4LTE4VDE0"
    "OjE4OjE1KzAyOjAwKJ1j3AAAAABJRU5ErkJggg==").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['DrawEllipse'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAACXBIWXMAAAsTAAALEwEAmpwY"
    "AAAA5ElEQVRYhe2WWQ6DMAxEx1XvBUdLbmafzP0oqbKYbhj8k5EiRBTwy3hEIFVFpG6h1ScA"
    "gPsvi0WkDgwty3IYwHSgK1TPUTVc0msCMLPHu7+TqjaDmRWAMrP288zc3PfP/jMGB7YiZLhA"
    "AFREtGrHYTUAIqIpJQBASsnKQp0BFzUAZfdEpL0LHok31fd++zS/rl69/piBsvsOzsqCq6gc"
    "RsX2YcHOvJfM7wARXXZENi3IOZcAEADknPWyFgDPndcF13UdcnEawDvbL8nAXpGzHQj/HwgH"
    "aEIYoXAHJsAEmAATIBzgASzTKthtoxiTAAAAAElFTkSuQmCC").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['DrawEnd'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgAgMAAAAOFJJnAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JgAAgIQAAPoAAACA6AAAdTAAAOpgAAA6mAAAF3CculE8AAAADFBMVEUBAgMAAACA"
    "gID///9fpk1YAAAAAXRSTlMAQObYZgAAAAFiS0dEAxEMTPIAAAAHdElNRQfhCBIOEg85efYa"
    "AAAARUlEQVQY02NggAMHDEYDlBZLRRdhcIMxPBOgDMYwKIMpFCYUCjNpKky1CExEQQAmxMKA"
    "AdJSYNZxwJzEgs6AS8EV0wQAAFHyCNebrGE6AAAAJXRFWHRkYXRlOmNyZWF0ZQAyMDE3LTA4"
    "LTE4VDE0OjE3OjM2KzAyOjAw2wadDQAAACV0RVh0ZGF0ZTptb2RpZnkAMjAxNy0wOC0xOFQx"
    "NDoxODoxNSswMjowMCidY9wAAAAASUVORK5CYII=").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['DrawRectangle'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAACXBIWXMAAAsTAAALEwEAmpwY"
    "AAAA0UlEQVRYhe2WWwrEIAxF752NtUurO0tWduejONRaBwaMMmDAj6o0J8f0QUmYGa+p2RfA"
    "LwDuLncvrsMAGjcnALl7XmcYgJm19hNAt+SPAO6u4zgqC9u24ZK827NbAZgZJPFu4aa9H4Sk"
    "zzAznVMCAJmZrusRozCQqyepJwsh0ap+lIWPgVz9DS7cAvPHKGuvNjTme8Xje4DksE9kcQQp"
    "pdwABICUkoYdAXBWfk2473vVF2EA37QP6YFWkmgD//M/EBVFE86I6QYWwAJYAAtgOsAbi8Eu"
    "VUcv3/wAAAAASUVORK5CYII=").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['DrawStart'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgBAMAAACBVGfHAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JgAAgIQAAPoAAACA6AAAdTAAAOpgAAA6mAAAF3CculE8AAAAD1BMVEUBAgP/AAAA"
    "AACAgID////e+dEAAAAAAXRSTlMAQObYZgAAAAFiS0dEBI9o2VEAAAAHdElNRQfhCBIOEg85"
    "efYaAAAASUlEQVQoz9XOsQ3AMAwDQYKeIBsI9AbZf7ikzQuIGzdWeSAekrbc1WACHMgIJakv"
    "3GGksBhy+6UI74RlMdQXCLus/IJsr6LH3QPwBQOyjzdP8gAAACV0RVh0ZGF0ZTpjcmVhdGUA"
    "MjAxNy0wOC0xOFQxNDoxNzozNiswMjowMNsGnQ0AAAAldEVYdGRhdGU6bW9kaWZ5ADIwMTct"
    "MDgtMThUMTQ6MTg6MTUrMDI6MDAonWPcAAAAAElFTkSuQmCC").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['EditAnchor'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgBAMAAACBVGfHAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JgAAgIQAAPoAAACA6AAAdTAAAOpgAAA6mAAAF3CculE8AAAAD1BMVEUBAgPAwMAA"
    "AACAgID///9hUlqkAAAAAXRSTlMAQObYZgAAAAFiS0dEBI9o2VEAAAAHdElNRQfhCBIOEg85"
    "efYaAAAAVUlEQVQoz8WPuw2AQAxDTVgghAUiT3Dc/sNBy6OgQcLlU/yJ9Ik2gjoAVoMsJpkk"
    "ZTOkGRLoGcJJiifX3AGww6TZepUbyfGo6nbeLNnYFyqG8Mk/dQJ27gU0/VtoiAAAACV0RVh0"
    "ZGF0ZTpjcmVhdGUAMjAxNy0wOC0xOFQxNDoxNzozNiswMjowMNsGnQ0AAAAldEVYdGRhdGU6"
    "bW9kaWZ5ADIwMTctMDgtMThUMTQ6MTg6MTUrMDI6MDAonWPcAAAAAElFTkSuQmCC").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['EditComponent'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgBAMAAACBVGfHAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JgAAgIQAAPoAAACA6AAAdTAAAOpgAAA6mAAAF3CculE8AAAAD1BMVEUBAgP/AAAA"
    "AACAgID////e+dEAAAAAAXRSTlMAQObYZgAAAAFiS0dEBI9o2VEAAAAHdElNRQfhCBIOEg85"
    "efYaAAAAOklEQVQoz2NgoAoQxBBQRhNgUkITYVZCF1FSUkAVMFJCN0QBTQUzAxOGWxTQBTCV"
    "gExCE1CiuoJhAQAeOwLkdi2jxwAAACV0RVh0ZGF0ZTpjcmVhdGUAMjAxNy0wOC0xOFQxNDox"
    "NzozNiswMjowMNsGnQ0AAAAldEVYdGRhdGU6bW9kaWZ5ADIwMTctMDgtMThUMTQ6MTg6MTUr"
    "MDI6MDAonWPcAAAAAElFTkSuQmCC").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['EditContour'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgBAMAAACBVGfHAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JgAAgIQAAPoAAACA6AAAdTAAAOpgAAA6mAAAF3CculE8AAAAElBMVEUBAgP/AAAA"
    "AACAgIDAwMD////dqDPgAAAAAXRSTlMAQObYZgAAAAFiS0dEBfhv6ccAAAAHdElNRQfhCBIO"
    "Eg85efYaAAAATUlEQVQoz2NgoAoQxBBQRhNgUkITYVZCF1FSUkAVMFJCN0QBTQUzAxOGWxQY"
    "nFFVMTEpGaCpUXJAV8KEbgghBU5oTsF0rbIDGSE5yAAAJSwE1hxasGwAAAAldEVYdGRhdGU6"
    "Y3JlYXRlADIwMTctMDgtMThUMTQ6MTc6MzYrMDI6MDDbBp0NAAAAJXRFWHRkYXRlOm1vZGlm"
    "eQAyMDE3LTA4LTE4VDE0OjE4OjE1KzAyOjAwKJ1j3AAAAABJRU5ErkJggg==").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['EditContourDirection'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAACXBIWXMAAAsTAAALEwEAmpwY"
    "AAABO0lEQVRYhe2WzU6FMBBGz8BNNMaFC13pq0Kn8KouXLhwZVwI44JrUktvpFx+NjSZkBSY"
    "7/AxnVbMjD1Hsav6AQCcRjMiBlAUpcxJ2HffWc9fdMD6zlxdrV+hZvYnpCgBLAxVNSlKpkSc"
    "779IAqiqxRBTQRYBSLkAJMVjqMUAYhcufXF8bzGA0IWU0OoOpJKnIIY6zhOdDDDFclW9CkDi"
    "zagox71ptHT7zuTcqKzvzMxmNS2Y2Yol6JKqOld7yDXHgXCs7oCrK/tty6mrqiIi5r03Oe8j"
    "OWN3Byarubp6ALrgHVPV581qwNXVCbj3TfsRzm/mAGCxOAwrIoTOPQ/kANwAn66uXoB34BEQ"
    "ht8iQOeb9i1LPRPAXF09Abe+ab+A11yxdNbMVhy14btrzwOjItx67H4qPgAOgAPgB+BLPQxY"
    "v+AIAAAAAElFTkSuQmCC").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['EditGuideline'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgBAMAAACBVGfHAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JgAAgIQAAPoAAACA6AAAdTAAAOpgAAA6mAAAF3CculE8AAAAD1BMVEUBAgP/AAAA"
    "AACAgID////e+dEAAAAAAXRSTlMAQObYZgAAAAFiS0dEBI9o2VEAAAAHdElNRQfhCBIOEg85"
    "efYaAAAAQUlEQVQoz2NgoAoQxBBQRhNgUkITYVZCF1FSUkAVMFJCN0QBTQUzAxOGWxQYDAxQ"
    "dTGga0NXwYCuwggIKFUxLAAAxrMFaIj+lE0AAAAldEVYdGRhdGU6Y3JlYXRlADIwMTctMDgt"
    "MThUMTQ6MTc6MzYrMDI6MDDbBp0NAAAAJXRFWHRkYXRlOm1vZGlmeQAyMDE3LTA4LTE4VDE0"
    "OjE4OjE1KzAyOjAwKJ1j3AAAAABJRU5ErkJggg==").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['EditHints'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgAgMAAAAOFJJnAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JQAAgIMAAPn/AACA6QAAdTAAAOpgAAA6mAAAF2+SX8VGAAAACVBMVEUBAgMAAAD/"
    "///na8ZxAAAAAXRSTlMAQObYZgAAAAFiS0dEAmYLfGQAAAAJcEhZcwAACxMAAAsTAQCanBgA"
    "AAAHdElNRQflCgENGjd4GZPSAAAAMElEQVQY02NgYGGAAlEYI9QBQjOGBkBF4GpgjNBQmCLc"
    "AKEGQzvCZLgxouhqBgcAAFpiBTfyCWVOAAAAJXRFWHRkYXRlOmNyZWF0ZQAyMDE3LTA5LTE2"
    "VDE0OjU5OjE3KzAyOjAwZiSkBgAAACV0RVh0ZGF0ZTptb2RpZnkAMjAyMS0xMC0wMVQxMzoy"
    "Njo1NSswMjowMGSAvS8AAAAASUVORK5CYII=").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 6)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 8)
cursors['EditHLine'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgBAMAAACBVGfHAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JgAAgIQAAPoAAACA6AAAdTAAAOpgAAA6mAAAF3CculE8AAAAD1BMVEUBAgPAwMAA"
    "AACAgID///9hUlqkAAAAAXRSTlMAQObYZgAAAAFiS0dEBI9o2VEAAAAHdElNRQfhCBIOEg85"
    "efYaAAAATElEQVQoz9WOsRHAIAwDBVkg4AU4TQDsPxzUT0GTJur8J8mSPlEhqAPgMUgyySSp"
    "NksaSzL+dMHyipY9twMEQppNdwXuxNSxV9a/tAAClgR90CbKlgAAACV0RVh0ZGF0ZTpjcmVh"
    "dGUAMjAxNy0wOC0xOFQxNDoxNzozNiswMjowMNsGnQ0AAAAldEVYdGRhdGU6bW9kaWZ5ADIw"
    "MTctMDgtMThUMTQ6MTg6MTUrMDI6MDAonWPcAAAAAElFTkSuQmCC").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['EditPoint'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgBAMAAACBVGfHAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JgAAgIQAAPoAAACA6AAAdTAAAOpgAAA6mAAAF3CculE8AAAAD1BMVEUBAgP/AAAA"
    "AACAgID////e+dEAAAAAAXRSTlMAQObYZgAAAAFiS0dEBI9o2VEAAAAHdElNRQfhCBIOEg85"
    "efYaAAAAQUlEQVQoz92MsQ0AIAzDovQCPqjCB/x/HKxNBxYmPFpOgCeMJqYJykzIjZRVLPlJ"
    "WhHgobr0EWGFJ0Qr2gcvxadskjwCTqXjMFoAAAAldEVYdGRhdGU6Y3JlYXRlADIwMTctMDgt"
    "MThUMTQ6MTc6MzYrMDI6MDDbBp0NAAAAJXRFWHRkYXRlOm1vZGlmeQAyMDE3LTA4LTE4VDE0"
    "OjE4OjE1KzAyOjAwKJ1j3AAAAABJRU5ErkJggg==").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['EditRubberBand'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgBAMAAACBVGfHAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JgAAgIQAAPoAAACA6AAAdTAAAOpgAAA6mAAAF3CculE8AAAAD1BMVEUBAgPAwMAA"
    "AACAgID///9hUlqkAAAAAXRSTlMAQObYZgAAAAFiS0dEBI9o2VEAAAAHdElNRQfhCBIOEg85"
    "efYaAAAATklEQVQoz2NgoAoQRBcQMkQTYFZCE2FUQhcxQhcRUlJCN0QB3RAmNHsMGNCUCDCg"
    "KwE61wBNQBhNE4ORAoYmBSDAHwoKDAyEVBA0Y5ABAGheBPCRDxl5AAAAJXRFWHRkYXRlOmNy"
    "ZWF0ZQAyMDE3LTA4LTE4VDE0OjE3OjM2KzAyOjAw2wadDQAAACV0RVh0ZGF0ZTptb2RpZnkA"
    "MjAxNy0wOC0xOFQxNDoxODoxNSswMjowMCidY9wAAAAASUVORK5CYII=").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['EditSelection'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgBAMAAACBVGfHAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JgAAgIQAAPoAAACA6AAAdTAAAOpgAAA6mAAAF3CculE8AAAAElBMVEUBAgP/AAAA"
    "AACAgIDAwMD////dqDPgAAAAAXRSTlMAQObYZgAAAAFiS0dEBfhv6ccAAAAHdElNRQfhCBIO"
    "Eg85efYaAAAATElEQVQoz2NgoAoQxBBQRhNgUkITYVZCF1FSUkAVMFJCN0QBTQUzAxOGWxRA"
    "6lB0QTGKGlSDmJjQVTijmcFigOZYJjTHYTiEsMAQAACxbgNpADg8sAAAACV0RVh0ZGF0ZTpj"
    "cmVhdGUAMjAxNy0wOC0xOFQxNDoxNzozNiswMjowMNsGnQ0AAAAldEVYdGRhdGU6bW9kaWZ5"
    "ADIwMTctMDgtMThUMTQ6MTg6MTUrMDI6MDAonWPcAAAAAElFTkSuQmCC").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['EditStartpoint'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAQAAADZc7J/AAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JQAAgIMAAPn/AACA6QAAdTAAAOpgAAA6mAAAF2+SX8VGAAAAAmJLR0QA/4ePzL8A"
    "AAAJcEhZcwAACxMAAAsTAQCanBgAAAAHdElNRQfhCQ8QMCMluPRRAAAAVUlEQVRIx+2QOw7A"
    "MAhD7Yj7X9kdUJM0G87SAUuwvceHEI6IKCROgKrgwEiIens1w538EYirLEEe4G0xT3CmA0As"
    "2FOE/77MHb3/oAUtaEELWvADwQNpWBRDo3v/gwAAACV0RVh0ZGF0ZTpjcmVhdGUAMjAxNy0w"
    "OS0xNVQxNjo0ODoyNiswMjowMCkEHRYAAAAldEVYdGRhdGU6bW9kaWZ5ADIwMTctMDktMTVU"
    "MTY6NDg6MzUrMDI6MDClG7+pAAAAAElFTkSuQmCC").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['Erase'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgBAMAAACBVGfHAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JQAAgIMAAPn/AACA6QAAdTAAAOpgAAA6mAAAF2+SX8VGAAAAFVBMVEX///8AAAD/"
    "AAABAgMAAAD/AAD////tUcaIAAAABHRSTlMAAAAAs5NmmgAAAAFiS0dEAIgFHUgAAAAJcEhZ"
    "cwAACxMAAAsTAQCanBgAAAAHdElNRQfhCQ8REgAhr6k0AAAAT0lEQVQoz2NwAQIHBiTgAMUI"
    "ARcWB1QBV1c0AREVBgIqXFQcUQUEGQRRBDDcgR0Ym7gYG6AKmKALoKswdkYVcDF2NnHAK2Ds"
    "7OyM39CRAgB3gRH88KbVTQAAACV0RVh0ZGF0ZTpjcmVhdGUAMjAxNy0wOS0xNVQxNzoxNzo1"
    "MyswMjowMCwzFeIAAAAldEVYdGRhdGU6bW9kaWZ5ADIwMTctMDktMTVUMTc6MTg6MDArMDI6"
    "MDDVbeIqAAAAAElFTkSuQmCC").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['EraseAnchor'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgBAMAAACBVGfHAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JQAAgIMAAPn/AACA6QAAdTAAAOpgAAA6mAAAF2+SX8VGAAAAGFBMVEX///8AAAD/"
    "AAABAgMAAAD/AADAwMD////vANanAAAABHRSTlMAAAAAs5NmmgAAAAFiS0dEAIgFHUgAAAAJ"
    "cEhZcwAACxMAAAsTAQCanBgAAAAHdElNRQfhCQ8RGhj6GrtqAAAAVElEQVQoz2NwAQIHBiTg"
    "AMUIARcWB1QBV1c0AREVBQIqXFQcUQUElQRRBDDcQSRgcTF2NkYWYHZGFzAxMXFD0eJmYmyC"
    "osLY2cwZTcDEhQzHDD8AACN2Dw/moPVYAAAAJXRFWHRkYXRlOmNyZWF0ZQAyMDE3LTA5LTE1"
    "VDE3OjI2OjIyKzAyOjAw9qEacAAAACV0RVh0ZGF0ZTptb2RpZnkAMjAxNy0wOS0xNVQxNzoy"
    "NjoyNCswMjowMOQsl/YAAAAASUVORK5CYII=").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['EraseComponent'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgCAYAAABzenr0AAAACXBIWXMAAAsTAAALEwEAmpwY"
    "AAABaElEQVRYhe1Vu3KDMBDck2jieCYp0iW/Ckj2b+YDUqRIlSaGdQF4ZI2whHikYWc0QnCj"
    "XfbuJAFAREBSYjG5KGIEIhIVOAfKJRrI3Oe1odwFe/JNmAMCRDoR3bxi3scEkAAE4B9uadAA"
    "oHRxN6y1dNdz0P8sZch570BXC0oL24aitLTN5UY2vBs2aZtLtoC7FACQzgc8D6QhGGOyCX30"
    "aY8EBRxwa0TpAu73KY4UoWJz8xrabFEHGGg6v7BcEUoXyzqQEuQLGnMgpxiTHPAx5kAOVOhl"
    "XZVk23BsNsZARGitnX1k/7sDD5nqqnwF0DhxNMa8b9YFdVUWAI72dP5xv/sOzEGsC+iTA93B"
    "9KhVpyDoQAg5PZ6C7KtsKQeyBIS6JHZ8LybAWnsA8FtX5QeAbwBv6C61xpm/UvebXAN1VT4B"
    "OAJ4safzZyh2UjpIJg1RenQYYw7uOnVPkukOrIXgXbAL2AXsArbEFRtnHQSnzLlLAAAAAElF"
    "TkSuQmCC").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['EraseGuideline'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgBAMAAACBVGfHAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JQAAgIMAAPn/AACA6QAAdTAAAOpgAAA6mAAAF2+SX8VGAAAAG1BMVEX///8AAAD/"
    "AAABAgMAAAD/AADAwMCAgID///9GAK5TAAAABHRSTlMAAAAAs5NmmgAAAAFiS0dEAIgFHUgA"
    "AAAJcEhZcwAACxMAAAsTAQCanBgAAAAHdElNRQfhCQ8REzAebajZAAAAQklEQVQoz2NwAQIH"
    "BiTgAMUIARcWB1QBV1c0AREVBQIqXFQcUQUElQRRBDDcQTYwK0YTSHdBEyhBFzBxporNwxAA"
    "AIh1DAXD/Gj4AAAAJXRFWHRkYXRlOmNyZWF0ZQAyMDE3LTA5LTE1VDE3OjE5OjQ2KzAyOjAw"
    "rGgKaAAAACV0RVh0ZGF0ZTptb2RpZnkAMjAxNy0wOS0xNVQxNzoxOTo0OCswMjowMI0KyYkA"
    "AAAASUVORK5CYII=").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['ErasePoint'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgBAMAAACBVGfHAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JQAAgIMAAPn/AACA6QAAdTAAAOpgAAA6mAAAF2+SX8VGAAAAFVBMVEX///8AAACB"
    "gYH////CwsLBwcH/AADvh1QtAAAAAXRSTlMAQObYZgAAAAFiS0dEAIgFHUgAAAAJcEhZcwAA"
    "CxMAAAsTAQCanBgAAAAHdElNRQflCgEOJSyo5M5bAAAAQklEQVQoz2NgwA4YFdAEhAzQFCij"
    "CQgZO6ApMBVAERAWDkRVoGiIqkAoGJXPqGqMpsDZEM0EYfwK2AQFURWMAhIBAO1pBOc8FykE"
    "AAAAJXRFWHRkYXRlOmNyZWF0ZQAyMDIxLTEwLTAxVDE0OjM3OjM5KzAyOjAwRy3UxgAAACV0"
    "RVh0ZGF0ZTptb2RpZnkAMjAyMS0xMC0wMVQxNDozNzo0NCswMjowMF1iBKMAAAAASUVORK5C"
    "YII=").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 1)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 13)
cursors['Knife'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgAgMAAAAOFJJnAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JgAAgIQAAPoAAACA6AAAdTAAAOpgAAA6mAAAF3CculE8AAAADFBMVEUBAgP//wAA"
    "AAD///9yrVWEAAAAAXRSTlMAQObYZgAAAAFiS0dEAxEMTPIAAAAHdElNRQfhCBIOEg85efYa"
    "AAAAM0lEQVQY02NggAHGCVAGRweUIaQIZWh0oYvA1TBOaICymBbATFoBY2jBGFzEKOJgGIQA"
    "AEK4B1WaBPU9AAAAJXRFWHRkYXRlOmNyZWF0ZQAyMDE3LTA4LTE4VDE0OjE3OjM2KzAyOjAw"
    "2wadDQAAACV0RVh0ZGF0ZTptb2RpZnkAMjAxNy0wOC0xOFQxNDoxODoxNSswMjowMCidY9wA"
    "AAAASUVORK5CYII=").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['MagicWand'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgBAMAAACBVGfHAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JgAAgIQAAPoAAACA6AAAdTAAAOpgAAA6mAAAF3CculE8AAAAD1BMVEUBAgMAAAC3"
    "t7dwcHD///8mxPxCAAAAAXRSTlMAQObYZgAAAAFiS0dEBI9o2VEAAAAHdElNRQfhCBIOEg85"
    "efYaAAAAMUlEQVQoz2NgYBBgQAWKggoofCYDASMUAUYGAUYUAUFBRkEBvCowzMCwBdMdo2AQ"
    "AADZSwIVWt8QKQAAACV0RVh0ZGF0ZTpjcmVhdGUAMjAxNy0wOC0xOFQxNDoxNzozNiswMjow"
    "MNsGnQ0AAAAldEVYdGRhdGU6bW9kaWZ5ADIwMTctMDgtMThUMTQ6MTg6MTUrMDI6MDAonWPc"
    "AAAAAElFTkSuQmCC").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['MarkCenter'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgBAMAAACBVGfHAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JQAAgIMAAPn/AACA6QAAdTAAAOpgAAA6mAAAF2+SX8VGAAAAElBMVEX/////AAAA"
    "AACAgIDAwMD///9LuXgMAAAAAXRSTlMAQObYZgAAAAFiS0dEAIgFHUgAAAAJcEhZcwAACxMA"
    "AAsTAQCanBgAAAAHdElNRQfhCRISMx+ADYA5AAAAQklEQVQoz2NgoA1gFFJGEzBAU8HEhC7A"
    "oIAqwMzABBZGBkAlCmjKmBzQTFJRQDWJyYGFicoKGBTQHYvhHXQFQxMAAILDA6FStFwRAAAA"
    "JXRFWHRkYXRlOmNyZWF0ZQAyMDE3LTA5LTE4VDE4OjUxOjI5KzAyOjAwEXvXHAAAACV0RVh0"
    "ZGF0ZTptb2RpZnkAMjAxNy0wOS0xOFQxODo1MTozMSswMjowMJ9jIVkAAAAASUVORK5CYII=").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['Meter'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgBAMAAACBVGfHAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JgAAgIQAAPoAAACA6AAAdTAAAOpgAAA6mAAAF3CculE8AAAAD1BMVEUBAgPAwMAA"
    "AACAgID///9hUlqkAAAAAXRSTlMAQObYZgAAAAFiS0dEBI9o2VEAAAAHdElNRQfhCBIOEg85"
    "efYaAAAARklEQVQoz83OyRUAEBRD0aABQwNOKkD/xbF+thayvCd/kJ6kEOoEJEOCKYtSbS7p"
    "XBJxZwiVLFbOuwPQMKTVdScS/bzwWzYCsAR8GJqo7QAAACV0RVh0ZGF0ZTpjcmVhdGUAMjAx"
    "Ny0wOC0xOFQxNDoxNzozNiswMjowMNsGnQ0AAAAldEVYdGRhdGU6bW9kaWZ5ADIwMTctMDgt"
    "MThUMTQ6MTg6MTUrMDI6MDAonWPcAAAAAElFTkSuQmCC").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['PointContour'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgBAMAAACBVGfHAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JgAAgIQAAPoAAACA6AAAdTAAAOpgAAA6mAAAF3CculE8AAAAD1BMVEUBAgOAgIAA"
    "AADAwMD////VfPkDAAAAAXRSTlMAQObYZgAAAAFiS0dEBI9o2VEAAAAHdElNRQfhCBIOEg85"
    "efYaAAAATElEQVQoz2NgoA5gVFJE4TMrMjAqIwswQTEcCAK5jAJIAgogeQVkASYlJVQBdBUY"
    "ZmDYAnKHErIKkEuZUN0KBKhKQIYQoYRKQTeoAQB44wMu4nAJLQAAACV0RVh0ZGF0ZTpjcmVh"
    "dGUAMjAxNy0wOC0xOFQxNDoxNzozNiswMjowMNsGnQ0AAAAldEVYdGRhdGU6bW9kaWZ5ADIw"
    "MTctMDgtMThUMTQ6MTg6MTUrMDI6MDAonWPcAAAAAElFTkSuQmCC").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['ZoomIn'] = wx.Cursor(image)

image = PyEmbeddedImage(
    "iVBORw0KGgoAAAANSUhEUgAAACAAAAAgBAMAAACBVGfHAAAABGdBTUEAALGPC/xhBQAAACBj"
    "SFJNAAB6JgAAgIQAAPoAAACA6AAAdTAAAOpgAAA6mAAAF3CculE8AAAAD1BMVEUBAgOAgIAA"
    "AADAwMD////VfPkDAAAAAXRSTlMAQObYZgAAAAFiS0dEBI9o2VEAAAAHdElNRQfhCBIOEg85"
    "efYaAAAASklEQVQoz2NgoA5gVFJE4TMrMjAqIwswQTEcCIJ0CSAJKMAJmACjkhKqALoKDDMw"
    "bAG5QwlZBcilTKhuBQJUJSBDiFBCpaAb1AAAa1ADJb7/oi4AAAAldEVYdGRhdGU6Y3JlYXRl"
    "ADIwMTctMDgtMThUMTQ6MTc6MzYrMDI6MDDbBp0NAAAAJXRFWHRkYXRlOm1vZGlmeQAyMDE3"
    "LTA4LTE4VDE0OjE4OjE1KzAyOjAwKJ1j3AAAAABJRU5ErkJggg==").GetImage()
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_X, 5)
image.SetOption(wx.IMAGE_OPTION_CUR_HOTSPOT_Y, 5)
cursors['ZoomOut'] = wx.Cursor(image)


del PyEmbeddedImage
del image
